/*!
 *  @file    main.c
 *  @author  Kang IkSeon (ikseon1026@gmail.com)
 *
 *  @internal
 *       Created:  2018년 01월 30일
 *     Copyright:  Copyright (c) 2018, Kang IkSeon
 */

#include <stdio.h>
#include <stdint.h>

#include "src/lib.h"

#define PACKET_LEN WOL_LEN + 14

int main() {
  int n, len;
  unsigned char packet[PACKET_LEN];
  char dmac[] = {0x08, 0x62, 0x66, 0x7c, 0xed, 0x6c};

  printf ("ether size : %zu\n", sizeof(struct ether_header));

  make_ether_packet(packet, dmac);
  make_wol_packet(packet + sizeof(struct ether_header), dmac);

  send_wol("enp0s25", packet, PACKET_LEN);

  return 0;
}
